@@ -120,7 +120,7 @@ class DumpResultSqlite(DumpResult):
 			(len(self.to_update_parents) > self.commit_frequency))
 
 	def update_db(self):
-		insert_keys = self.to_insert.keys()
+		insert_keys = list(self.to_insert.keys())
 
 		for key in insert_keys:
 			# create a new saved copy in the db:
@@ -135,7 +135,7 @@ class DumpResultSqlite(DumpResult):
 			del self.to_insert[key]
 			del self.to_insert_parents[key]
 
-		update_keys = self.to_update.keys()
+		update_keys = list(self.to_update.keys())
 
 		for key in update_keys:
 			# get previous saved copy:
